@@ -36,7 +36,7 @@ class ProgramChange(MIDIMessage):
         self.patch = patch
         super().__init__(channel=channel)
         if not 0 <= self.patch <= 127:
-            raise self._EX_VALUEERROR_OOR
+            self._raise_valueerror_oor()
 
     def __bytes__(self):
         return bytes([self._STATUS | (self.channel & self.CHANNELMASK), self.patch])
